Date: 07 17, 2001 11:18:26 AM

# Adding Samples to Rule Concepts

There are several ways to add samples to a rule concept. You can add samples to rules by highlighting example text from a text file in the Workspace, or by importing lists of samples from an existing text file.

To add samples using a text file in the Workspace:

1. Double click on the text file in the Text Tab to open it in the Workspace.

2. In the Gram Tab, select the rule concept you want to add samples to. The arrow in front of the rule concept turns blue.

3. In the text file, highlight the word (or phrase) that corresponds to the rule concept.

4. Right click and select the rule concept name listed in the pulldown menu. The sample is added below and indented to the right of the rule concept.

Tip: If you are using folders to organize your rule concepts, select the folder instead of the individual rule concept to see all the rule concepts in the pulldown menu when you highlight text.

Adding samples already contained in a file is a fast and easy way to add samples to a rule concept. This is particularly helpful when you have lists of names or other such data.

To add samples by importing a text file:

1. In the Gram Tab, select the rule concept you want to add samples to. The arrow in front of the rule concept turns blue.

2. Right-click and select Sample File > Import.

3. VisualText will warn you that importing samples from a file will delete any samples you may have for the rule concept. Since you don't have any samples for the rule concept yet, click Yes. The warning is for those who already have samples for the rule concept.

4. In the Open dialog, navigate to the directory containing the file of samples.

5. Select the file you want to import and click Open. The samples are added below and indented to the right of the rule concept.

Note: Each line of your text file must contain one sample only.

WARNING: Make sure all edits to be made from a text file you are sampling have been made to the file BEFORE you start sampling. Once you start sampling the file, you can't edit it.